@@ -39,3 +39,19 @@ class pair_in_list:
                 print ("Pair with sum " + str(desired_sum) + " is (" + str(self.given_list[i]) + ", " + str(temp) + ")")
                 pass
             s.add(self.given_list[i] )
+
+
+def if_sum(given_list, desired_sum):
+    """
+    Args: The sum to be checked
+    """
+    # Create an empty set
+    s = set()
+
+    for i in range(0, len(given_list)):
+        temp = desired_sum - given_list[i]
+        if (temp in s):
+            return True
+        s.add(given_list[i])
+
+    return False
